@@ -226,7 +226,7 @@ class Synchronizer:
     def _assign_field_data(self, instance, api_instance):
         raise NotImplementedError
 
-    def fetch_sync_by_id(self, instance_id):
+    def fetch_sync_by_id(self, instance_id, sync_config={}):
         api_instance = self.get_single(instance_id)
         instance, created = self.update_or_create_instance(api_instance)
         return instance
@@ -594,7 +594,10 @@ class ServiceNoteSynchronizer(CallbackPartialSyncMixin, Synchronizer):
                 "Invalid target type for note creation: {}.".format(
                     str(target.__class__))
             )
-        service_client = api.ServiceAPIClient()
+        service_client = api.ServiceAPIClient(
+            api_public_key=kwargs.get('api_public_key'),
+            api_private_key=kwargs.get('api_private_key')
+        )
         instance = service_client.post_note(target_data, **kwargs)
 
         return self.update_or_create_instance(instance)
@@ -1180,7 +1183,10 @@ class ScheduleEntriesSynchronizer(BatchConditionMixin, Synchronizer):
         create it in the local database from the response
 
         """
-        schedule_client = api.ScheduleAPIClient()
+        schedule_client = api.ScheduleAPIClient(
+            api_public_key=kwargs.get('api_public_key'),
+            api_private_key=kwargs.get('api_private_key')
+        )
         # Type defines if it is a service ticket, opportunity, or activity.
         # (There are more but we probably wont be using them).
         # In the context of schedule entry types, Service Tickets and
@@ -1368,7 +1374,11 @@ class TimeEntrySynchronizer(BatchConditionMixin,
                 "Invalid target type for TimeEntry "
                 "creation: " + str(target.__class__) + "."
             )
-        time_client = api.TimeAPIClient()
+
+        time_client = api.TimeAPIClient(
+            api_public_key=kwargs.get('api_public_key'),
+            api_private_key=kwargs.get('api_private_key')
+        )
         instance = time_client.post_time_entry(target_data, **kwargs)
         return self.update_or_create_instance(instance)
 
@@ -1847,28 +1857,32 @@ class TicketSynchronizerMixin:
     def get_single(self, ticket_id):
         return self.client.get_ticket(ticket_id)
 
-    def sync_related(self, instance):
+    # sync_config is read-only, so mutable argument is used for simplicity.
+    def sync_related(self, instance, sync_config={}):
         instance_id = instance.id
         sync_classes = []
 
-        note_sync = ServiceNoteSynchronizer()
-        note_sync.api_conditions = [instance_id]
-        sync_classes.append((note_sync, Q(ticket=instance)))
+        if sync_config.get('sync_service_note', True):
+            note_sync = ServiceNoteSynchronizer()
+            note_sync.api_conditions = [instance_id]
+            sync_classes.append((note_sync, Q(ticket=instance)))
 
-        time_sync = TimeEntrySynchronizer()
-        time_sync.batch_condition_list = [instance_id]
-        sync_classes.append((time_sync, Q(charge_to_id=instance)))
+        if sync_config.get('sync_time_entry', True):
+            time_sync = TimeEntrySynchronizer()
+            time_sync.batch_condition_list = [instance_id]
+            sync_classes.append((time_sync, Q(charge_to_id=instance)))
 
-        activity_sync = ActivitySynchronizer()
-        activity_sync.api_conditions = ['ticket/id={}'.format(instance_id)]
-        sync_classes.append((activity_sync, Q(ticket=instance)))
+        if sync_config.get('sync_activity', True):
+            activity_sync = ActivitySynchronizer()
+            activity_sync.api_conditions = ['ticket/id={}'.format(instance_id)]
+            sync_classes.append((activity_sync, Q(ticket=instance)))
 
         self.sync_children(*sync_classes)
 
-    def fetch_sync_by_id(self, instance_id):
+    def fetch_sync_by_id(self, instance_id, sync_config={}):
         instance = super().fetch_sync_by_id(instance_id)
         if not instance.closed_flag:
-            self.sync_related(instance)
+            self.sync_related(instance, sync_config)
         return instance
 
     def _instance_ids(self, filter_params=None):
